==> zio-aws-pinpointemail_3-5.17.112.1-sources.jar: zio/aws/pinpointemail/model/Template.scala <==
package zio.aws.pinpointemail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpointemail.model.primitives.{TemplateData, TemplateArn}
import scala.jdk.CollectionConverters.*
final case class Template(
    templateArn: Option[TemplateArn] = None,
    templateData: Option[TemplateData] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.Template = {
    import Template.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.Template
      .builder()
      .optionallyWith(
        templateArn.map(value => TemplateArn.unwrap(value): java.lang.String)
      )(_.templateArn)
      .optionallyWith(
        templateData.map(value => TemplateData.unwrap(value): java.lang.String)
      )(_.templateData)
      .build()
  }
  def asReadOnly: zio.aws.pinpointemail.model.Template.ReadOnly =
    zio.aws.pinpointemail.model.Template.wrap(buildAwsValue())
}
object Template {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.Template
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpointemail.model.Template =
      zio.aws.pinpointemail.model.Template(
        templateArn.map(value => value),
        templateData.map(value => value)
      )
    def templateArn: Option[TemplateArn]
    def templateData: Option[TemplateData]
    def getTemplateArn: ZIO[Any, AwsError, TemplateArn] =
      AwsError.unwrapOptionField("templateArn", templateArn)
    def getTemplateData: ZIO[Any, AwsError, TemplateData] =
      AwsError.unwrapOptionField("templateData", templateData)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.Template
  ) extends zio.aws.pinpointemail.model.Template.ReadOnly {
    override val templateArn: Option[TemplateArn] = scala
      .Option(impl.templateArn())
      .map(value => zio.aws.pinpointemail.model.primitives.TemplateArn(value))
    override val templateData: Option[TemplateData] = scala
      .Option(impl.templateData())
      .map(value => zio.aws.pinpointemail.model.primitives.TemplateData(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.Template
  ): zio.aws.pinpointemail.model.Template.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpointemail_3-5.17.194.1-sources.jar: zio/aws/pinpointemail/model/Template.scala <==
package zio.aws.pinpointemail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpointemail.model.primitives.{TemplateData, TemplateArn}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Template(
    templateArn: Optional[TemplateArn] = Optional.Absent,
    templateData: Optional[TemplateData] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.Template = {
    import Template.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.Template
      .builder()
      .optionallyWith(
        templateArn.map(value => TemplateArn.unwrap(value): java.lang.String)
      )(_.templateArn)
      .optionallyWith(
        templateData.map(value => TemplateData.unwrap(value): java.lang.String)
      )(_.templateData)
      .build()
  }
  def asReadOnly: zio.aws.pinpointemail.model.Template.ReadOnly =
    zio.aws.pinpointemail.model.Template.wrap(buildAwsValue())
}
object Template {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.Template
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpointemail.model.Template =
      zio.aws.pinpointemail.model.Template(
        templateArn.map(value => value),
        templateData.map(value => value)
      )
    def templateArn: Optional[TemplateArn]
    def templateData: Optional[TemplateData]
    def getTemplateArn: ZIO[Any, AwsError, TemplateArn] =
      AwsError.unwrapOptionField("templateArn", templateArn)
    def getTemplateData: ZIO[Any, AwsError, TemplateData] =
      AwsError.unwrapOptionField("templateData", templateData)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.Template
  ) extends zio.aws.pinpointemail.model.Template.ReadOnly {
    override val templateArn: Optional[TemplateArn] = zio.aws.core.internal
      .optionalFromNullable(impl.templateArn())
      .map(value => zio.aws.pinpointemail.model.primitives.TemplateArn(value))
    override val templateData: Optional[TemplateData] = zio.aws.core.internal
      .optionalFromNullable(impl.templateData())
      .map(value => zio.aws.pinpointemail.model.primitives.TemplateData(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.Template
  ): zio.aws.pinpointemail.model.Template.ReadOnly = new Wrapper(impl)
}
